@@ -369,7 +369,7 @@
 #' 42(9): 1-21.  \doi{10.18637/jss.v042.i09}.
 #'
 #' Daniel Pemstein, Kevin M. Quinn, and Andrew D. Martin.  2007.  \emph{Scythe
-#' Statistical Library 1.0.} \url{http://scythe.lsa.umich.edu}.
+#' Statistical Library 1.0.} \url{http://scythe.wustl.edu.s3-website-us-east-1.amazonaws.com/}.
 #'
 #' Radford Neal. 2003. ``Slice Sampling'' (with discussion). \emph{Annals of
 #' Statistics}, 31: 705-767.
@@ -490,7 +490,7 @@
 "MCMCmnl" <-
   function(formula, baseline=NULL, data=NULL,
            burnin = 1000, mcmc = 10000, thin=1,
-           mcmc.method = c("IndMH", "RWM", "slice"),
+           mcmc.method = "IndMH", 
            tune = 1.0, tdf=6, verbose = 0, seed = NA,
            beta.start = NA, b0 = 0, B0 = 0, ...) {
 
@@ -623,6 +623,10 @@
                                  title="MCMCmnl Posterior Sample")
 
     }
+    else{
+        cat("\n\nmcmc.method not equal to one of 'RWM', 'IndMH', or 'slice'.\n")
+        stop("Please respecifify and call MCMCmnl() again.\n")
+    }
 
     return(output)
 
