@@ -165,6 +165,10 @@
 #' models."  \emph{Journal of Econometrics}. 86: 221-241.
 #' <doi: 10.1080/01621459.1995.10476635>
 #'
+#' Andrew D. Martin, Kevin M. Quinn, and Jong Hee Park. 2011.
+#' ``MCMCpack: Markov Chain Monte Carlo in R.'', \emph{Journal of
+#' Statistical Software}.  42(9): 1-21. \doi{10.18637/jss.v042.i09}.
+#'
 #' @keywords models
 #'
 #' @examples
@@ -264,7 +268,7 @@
     sos <- ifelse(random.perturb, 1, 0)
 
     if (m == 0){
-      output <- MCMCregress(formula, burnin = burnin, mcmc = mcmc,
+      output <- MCMCregress(formula, data=data, burnin = burnin, mcmc = mcmc,
                             thin = thin, verbose = verbose,
                             b0 = b0, B0 = B0, c0 =c0, d0=d0,
                             marginal.likelihood = "Chib95")
