@@ -1165,8 +1165,8 @@ namespace scythe {
                 - below) + below;
           }
           if (! R_finite(x)) {
-            SCYTHE_WARN("Mean extremely far from truncation point. "
-                << "Returning truncation point");
+            // SCYTHE_WARN("Mean extremely far from truncation point. "
+            //    << "Returning truncation point");
             return below;
           }
           return x;
@@ -1235,8 +1235,8 @@ namespace scythe {
                   - below) + below;
           }
           if (! R_finite(x)) {
-            SCYTHE_WARN("Mean extremely far from truncation point. "
-                << "Returning truncation point");
+            // SCYTHE_WARN("Mean extremely far from truncation point. "
+            //    << "Returning truncation point");
             return above;
           }
           return -1*x;
@@ -1311,7 +1311,9 @@ namespace scythe {
         // and wouldn't get inlined.
         const_matrix_forward_iterator<double,O,O,S> ait;
         const_matrix_forward_iterator<double,O,O,S> alast
-          = alpha.template end_f();
+	  //  = alpha.template end_f();
+	  // patch by mattblackwell 2018-08-27
+	  = alpha.end_f();
         typename Matrix<double,O,Concrete>::forward_iterator yit
           = y.begin_f();
         for (ait = alpha.begin_f(); ait != alast; ++ait) {
